# Generated by Django 5.1 on 2024-08-13 23:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0006_partner_services'),
    ]

    operations = [
        migrations.AddField(
            model_name='position',
            name='partner',
            field=models.ForeignKey(blank=True, help_text='Partner of position', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner'),
        ),
    ]



# Generated by Django 5.1 on 2025-01-18 04:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_partner", "0008_partner_document_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="partner",
            name="document_type",
            field=models.CharField(
                blank=True,
                choices=[
                    ("DNI", "DNI"),
                    ("CC", "CÉDULA"),
                    ("CE", "CÉDULA DE EXTRANJERÍA"),
                    ("PAS", "PASAPORTE"),
                    ("PEP", "PERMISO ESPECIAL DE PERMANENCIA"),
                    ("LICE", "LICENCIA DE CONDUCCIÓN"),
                    ("NSS", "NÚMERO DE SEGURIDAD SOCIAL"),
                    ("NIT", "NIT"),
                    ("RUT", "RUT"),
                    ("NUIP", "NUIP"),
                    ("TI", "TARJETA DE IDENTIDAD"),
                    ("OTR", "OTRO"),
                ],
                help_text="Document type of partner",
                max_length=10,
                null=True,
                verbose_name="Document type",
            ),
        ),
    ]



# Generated by Django 5.0.1 on 2024-01-28 21:54

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("artd_location", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Position",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "name",
                    models.CharField(
                        help_text="Name of position",
                        max_length=150,
                        verbose_name="name",
                    ),
                ),
            ],
            options={
                "verbose_name": "Position",
                "verbose_name_plural": "Positions",
            },
        ),
        migrations.CreateModel(
            name="Partner",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "partner_slug",
                    models.SlugField(
                        help_text="Slug of headquarter",
                        max_length=150,
                        verbose_name="slug",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        help_text="Name of partner", max_length=150, verbose_name="name"
                    ),
                ),
                (
                    "dni",
                    models.CharField(
                        help_text="DNI of partner", max_length=20, verbose_name="dni"
                    ),
                ),
                (
                    "email",
                    models.EmailField(
                        help_text="Email of partner",
                        max_length=254,
                        verbose_name="email",
                    ),
                ),
                (
                    "address",
                    models.CharField(
                        help_text="Address of partner",
                        max_length=250,
                        verbose_name="address",
                    ),
                ),
                (
                    "city",
                    models.ForeignKey(
                        help_text="City of partner",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_location.city",
                        verbose_name="city",
                    ),
                ),
            ],
            options={
                "verbose_name": "Partner",
                "verbose_name_plural": "Partners",
            },
        ),
        migrations.CreateModel(
            name="Headquarter",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "name",
                    models.CharField(
                        help_text="Name of headquarter",
                        max_length=150,
                        verbose_name="name",
                    ),
                ),
                (
                    "address",
                    models.CharField(
                        help_text="Address of headquarter",
                        max_length=250,
                        verbose_name="address",
                    ),
                ),
                (
                    "phone",
                    models.CharField(
                        help_text="Phone of headquarter",
                        max_length=20,
                        verbose_name="phone",
                    ),
                ),
                (
                    "city",
                    models.ForeignKey(
                        help_text="City of headquarter",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_location.city",
                        verbose_name="city",
                    ),
                ),
                (
                    "partner",
                    models.ForeignKey(
                        help_text="Partner of headquarter",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_partner.partner",
                        verbose_name="partner",
                    ),
                ),
            ],
            options={
                "verbose_name": "Headquarter",
                "verbose_name_plural": "Headquarters",
            },
        ),
        migrations.CreateModel(
            name="Coworker",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "first_name",
                    models.CharField(
                        help_text="First name of coworker",
                        max_length=150,
                        verbose_name="first_name",
                    ),
                ),
                (
                    "last_name",
                    models.CharField(
                        help_text="Last name of coworker",
                        max_length=150,
                        verbose_name="last_name",
                    ),
                ),
                (
                    "dni",
                    models.CharField(
                        help_text="DNI of coworker", max_length=20, verbose_name="dni"
                    ),
                ),
                (
                    "email",
                    models.EmailField(
                        help_text="Email of coworker",
                        max_length=254,
                        verbose_name="email",
                    ),
                ),
                (
                    "phone",
                    models.CharField(
                        help_text="Phone of coworker",
                        max_length=20,
                        verbose_name="phone",
                    ),
                ),
                (
                    "headquarter",
                    models.ForeignKey(
                        help_text="Headquarter of coworker",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_partner.headquarter",
                        verbose_name="headquarter",
                    ),
                ),
                (
                    "position",
                    models.ForeignKey(
                        help_text="Position of coworker",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_partner.position",
                        verbose_name="position",
                    ),
                ),
            ],
            options={
                "verbose_name": "Coworker",
                "verbose_name_plural": "Coworkers",
            },
        ),
    ]



# Generated by Django 5.1 on 2025-03-06 00:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_partner", "0009_alter_partner_document_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="partner",
            name="signed_key",
            field=models.CharField(
                blank=True,
                help_text="Signed key of partner",
                max_length=250,
                null=True,
                verbose_name="Signed key",
            ),
        ),
    ]



from django.db import models

# Create your models here.
from django.db import models
from django.utils.translation import gettext_lazy as _
from artd_location.models import City
from artd_service.models import Service

DOCUMENT_TYPES = (
    ("DNI", _("DNI")),
    ("CC", _("CÉDULA")),
    ("CE", _("CÉDULA DE EXTRANJERÍA")),
    ("PAS", _("PASAPORTE")),
    ("PEP", _("PERMISO ESPECIAL DE PERMANENCIA")),
    ("LICE", _("LICENCIA DE CONDUCCIÓN")),
    ("NSS", _("NÚMERO DE SEGURIDAD SOCIAL")),
    ("NIT", _("NIT")),
    ("RUT", _("RUT")),
    ("NUIP", _("NUIP")),
    ("TI", _("TARJETA DE IDENTIDAD")),
    ("OTR", _("OTRO")),
)


class PartnerBaseModel(models.Model):
    created_at = models.DateTimeField(
        _("Created at"),
        help_text=_("Created at"),
        auto_now_add=True,
    )
    updated_at = models.DateTimeField(
        _("Updated at"),
        help_text=_("Updated at"),
        auto_now=True,
    )
    status = models.BooleanField(
        _("Status"),
        help_text=_("Status"),
        default=True,
    )

    class Meta:
        abstract = True


class Partner(PartnerBaseModel):
    """Model definition for Partner."""

    partner_slug = models.SlugField(
        _("Slug"),
        help_text=_("Slug of headquarter"),
        max_length=150,
    )
    name = models.CharField(
        _("Name"),
        help_text=_("Name of partner"),
        max_length=150,
    )
    document_type = models.CharField(
        _("Document type"),
        help_text=_("Document type of partner"),
        max_length=10,
        choices=DOCUMENT_TYPES,
        null=True,
        blank=True,
    )
    dni = models.CharField(
        _("Dni"),
        help_text=_("DNI of partner"),
        max_length=20,
    )
    email = models.EmailField(
        _("Email"),
        help_text=_("Email of partner"),
        max_length=254,
    )
    city = models.ForeignKey(
        City,
        verbose_name=_("City"),
        help_text=_("City of partner"),
        on_delete=models.CASCADE,
    )
    address = models.CharField(
        _("Address"),
        help_text=_("Address of partner"),
        max_length=250,
    )
    services = models.ManyToManyField(
        Service,
        verbose_name=_("Services"),
        help_text=_("Services of partner"),
    )
    signed_key = models.CharField(
        _("Signed key"),
        help_text=_("Signed key of partner"),
        max_length=250,
        null=True,
        blank=True,
    )

    class Meta:
        """Meta definition for Partner."""

        verbose_name = _("Partner")
        verbose_name_plural = _("Partners")

    def __str__(self):
        """Unicode representation of Partner."""
        return self.name


class Headquarter(PartnerBaseModel):
    """Model definition for Headquarter."""

    name = models.CharField(
        _("Name"),
        help_text=_("Name of headquarter"),
        max_length=150,
    )
    address = models.CharField(
        _("Address"),
        help_text=_("Address of headquarter"),
        max_length=250,
    )
    city = models.ForeignKey(
        City,
        verbose_name=_("City"),
        help_text=_("City of headquarter"),
        on_delete=models.CASCADE,
    )
    phone = models.CharField(
        _("phone"),
        help_text=_("Phone of headquarter"),
        max_length=20,
    )
    partner = models.ForeignKey(
        Partner,
        verbose_name=_("partner"),
        help_text=_("Partner of headquarter"),
        on_delete=models.CASCADE,
    )

    class Meta:
        """Meta definition for Headquarter."""

        verbose_name = _("Headquarter")
        verbose_name_plural = _("Headquarters")

    def __str__(self):
        """Unicode representation of Headquarter."""
        return self.name


class Position(PartnerBaseModel):
    """Model definition for Position."""

    name = models.CharField(
        _("Name"),
        help_text=_("Name of position"),
        max_length=150,
    )
    partner = models.ForeignKey(
        Partner,
        verbose_name=_("Partner"),
        help_text=_("Partner of position"),
        on_delete=models.CASCADE,
        blank=True,
        null=True,
    )

    class Meta:
        """Meta definition for Position."""

        verbose_name = _("Position")
        verbose_name_plural = _("Positions")

    def __str__(self):
        """Unicode representation of Position."""
        return self.name


class Coworker(PartnerBaseModel):
    """Model definition for Coworker."""

    first_name = models.CharField(
        _("First name"),
        help_text=_("First name of coworker"),
        max_length=150,
    )
    last_name = models.CharField(
        _("Last name"),
        help_text=_("Last name of coworker"),
        max_length=150,
    )
    dni = models.CharField(
        _("Dni"),
        help_text=_("DNI of coworker"),
        max_length=20,
    )
    email = models.EmailField(
        _("email"),
        help_text=_("Email of coworker"),
        max_length=254,
    )
    phone = models.CharField(
        _("Phone"),
        help_text=_("Phone of coworker"),
        max_length=20,
    )
    headquarter = models.ForeignKey(
        Headquarter,
        verbose_name=_("Headquarter"),
        help_text=_("Headquarter of coworker"),
        on_delete=models.CASCADE,
    )
    position = models.ForeignKey(
        Position,
        verbose_name=_("Position"),
        help_text=_("Position of coworker"),
        on_delete=models.CASCADE,
    )

    class Meta:
        """Meta definition for Coworker."""

        verbose_name = _("Coworker")
        verbose_name_plural = _("Coworkers")

    def __str__(self):
        """Unicode representation of Coworker."""
        return self.first_name + " " + self.last_name



import random
import string


def generate_random_string(lenght=10):
    """Method to generate an aleatory string"""
    return "".join(
        random.choices(
            string.ascii_lowercase + string.ascii_uppercase + string.digits,
            k=lenght,
        )
    )


def generate_random_number(lenght=10):
    """Method to generate an aleatory number"""
    number_string = "".join(
        random.choices(
            string.digits,
            k=lenght,
        )
    )
    return int(number_string)


def generate_random_boolean(lenght=10):
    """Method to generate an aleatory bool"""
    randInt = random.getrandbits(1)
    return bool(randInt)


def generate_random_float(from_float=0.1, to_float=100):
    """Method to generate a random float"""
    return random.uniform(from_float, to_float)


def generate_random_email():
    """Method to generate a random email"""
    validchars = "abcdefghijklmnopqrstuvwxyz1234567890"
    loginlen = random.randint(4, 15)
    login = ""
    for i in range(loginlen):
        pos = random.randint(0, len(validchars) - 1)
        login = login + validchars[pos]
    if login[0].isnumeric():
        pos = random.randint(0, len(validchars) - 10)
        login = validchars[pos] + login
    servers = ["@gmail", "@yahoo", "@redmail", "@hotmail", "@bing"]
    servpos = random.randint(0, len(servers) - 1)
    email = login + servers[servpos]
    tlds = [".com", ".in", ".gov", ".ac.in", ".net", ".org"]
    tldpos = random.randint(0, len(tlds) - 1)
    email = email + tlds[tldpos]
    return email



# Generated by Django 5.1 on 2025-01-17 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_partner", "0007_position_partner"),
    ]

    operations = [
        migrations.AddField(
            model_name="partner",
            name="document_type",
            field=models.CharField(
                blank=True,
                choices=[
                    ("DNI", "DNI"),
                    ("CC", "CÉDULA"),
                    ("CE", "CÉDULA DE EXTRANJERÍA"),
                    ("PAS", "PASAPORTE"),
                    ("PEP", "PERMISO ESPECIAL DE PERMANENCIA"),
                    ("NIT", "NIT"),
                    ("RUT", "RUT"),
                    ("NUIP", "NUIP"),
                    ("TI", "TARJETA DE IDENTIDAD"),
                    ("OTR", "OTRO"),
                ],
                help_text="Document type of partner",
                max_length=10,
                null=True,
                verbose_name="Document type",
            ),
        ),
    ]
